@@ -1,40 +1,24 @@
 /*
-    Copyright 2008,2011 Will Stephenson <wstephenson@kde.org>
-    Copyright 2011-2013 Lamarque V. Souza <lamarque@kde.org>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2008, 2011 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2011-2013 Lamarque V. Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_WIRELESSDEVICE_H
 #define NETWORKMANAGERQT_WIRELESSDEVICE_H
 
-#include <networkmanagerqt/networkmanagerqt_export.h>
-#include "device.h"
 #include "accesspoint.h"
+#include "device.h"
 #include "wirelessnetwork.h"
+#include <networkmanagerqt/networkmanagerqt_export.h>
 
-#include <QDBusObjectPath>
 #include <QDBusPendingReply>
 
 namespace NetworkManager
 {
-
 class WirelessDevicePrivate;
 
 /**
@@ -55,7 +39,7 @@ public:
         Unknown = 0, /**< not associated with a network */
         Adhoc, /**< part of an adhoc network */
         Infra, /**< a station in an infrastructure wireless network */
-        ApMode /**< access point in an infrastructure network */
+        ApMode, /**< access point in an infrastructure network */
     };
     Q_ENUM(OperationMode)
     /**
@@ -74,8 +58,9 @@ public:
         AdhocCap = 0x80, /**< The device supports Ad-Hoc mode. */
         FreqValid = 0x100, /**< The device properly reports information about supported frequencies */
         Freq2Ghz = 0x200, /**< The device supports 2.4Ghz frequencies */
-        Freq5Ghz = 0x400 /**< The device supports 5Ghz frequencies */
-
+        Freq5Ghz = 0x400, /**< The device supports 5Ghz frequencies */
+        Mesh = 0x1000, /**< The device supports acting as a mesh point */
+        IBSSRsn = 0x2000, /**< device supports WPA2/RSN in an IBSS network */
     };
     Q_DECLARE_FLAGS(Capabilities, Capability)
     /**
@@ -99,7 +84,8 @@ public:
     /**
      * Asks the device for a new scan of available wireless networks
      * @param options Options of scan
-     * No documentation for options yet, see http://projects.gnome.org/NetworkManager/developers/api/09/spec.html#org.freedesktop.NetworkManager.Device.Wireless
+     * No documentation for options yet, see
+     * https://projects.gnome.org/NetworkManager/developers/api/09/spec.html#org.freedesktop.NetworkManager.Device.Wireless
      */
     QDBusPendingReply<> requestScan(const QVariantMap &options = QVariantMap());
     /**
@@ -236,5 +222,4 @@ private:
 };
 
 } // namespace NetworkManager
-#endif //NETWORKMANAGERQT_WIRELESSDEVICE_H
-
+#endif // NETWORKMANAGERQT_WIRELESSDEVICE_H
